@@ -1,15 +1,29 @@
 /*
- * Remote Plugin for the Video Disk Recorder
+ * Remote Control plugin for the Video Disk Recorder
  *
  * remotetcp.c: tcp/telnet remote control
  *
- * See the README file for copyright information and how to reach the author.
+ * Copyright (C) 2002-2012 Oliver Endriss <o.endriss@gmx.de>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * Or, point your browser to http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
  */
 
 
 #include "remote.h"
 #include "remotetcp.h"
-#include "ttystatus.h"
 
 
 cTcpRemote::cTcpRemote(const char *name, int f, char *d)
@@ -26,7 +40,10 @@ cTcpRemote::~cTcpRemote()
     Cancel();
 
     if (cstatus)
+    {
         delete cstatus;
+        cstatus = NULL;
+    }
 
     if (fh != -1)
         close(fh);
@@ -84,8 +101,11 @@ uint64_t cTcpRemote::getKey(void)
 
     if (key == INVALID_KEY)
     {
-        delete cstatus;
-        cstatus = NULL;
+        if (cstatus)
+        {
+            delete cstatus;
+            cstatus = NULL;
+        }
         close(fh);
         fh = -1;
     }
